pygeodesy.rhumb.bases

Package pygeodesy :: Package rhumb :: Module bases |
[frames] | no frames]

# Module bases

(INTERNAL) base classes `RhumbBase` and `RhumbLineBase`, pure Python version of Karney's C++ classes Rhumb and RhumbLine from GeographicLib versions 2.0 and 2.2 and Karney's C++ example Rhumb intersect.

Class RhumbLineBase has been enhanced with methods `Intersecant2`, `Intersection` and `PlumbTo` to iteratively find the intersection of a rhumb line and a circle or an other rhumb line, respectively a perpendicular geodesic or other rhumb line.

For more details, see the C++ GeographicLib documentation, especially the Class List, the background information on Rhumb lines, the utily RhumbSolve and Online rhumb line calculations.

Copyright (C) Charles Karney (2014-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Version: 25.05.12

Classes
| RhumbBase (INTERNAL) Base class for `rhumb.aux_.RhumbAux` and `rhumb.ekx.Rhumb`.
| RhumbLineBase (INTERNAL) Base class for `rhumb.aux_.RhumbLineAux` and `rhumb.ekx.RhumbLine`.